@@ -52,51 +52,51 @@ AA_TABLE_REVERSED <- AA_TABLE_REVERSED[order(names(AA_TABLE_REVERSED))]
 #' 
 #' @name segments.alphabets
 #' 
-#' @aliases genealphabets HUMAN_TRAV_ALPHABET HUMAN_TRAJ_ALPHABET HUMAN_TRBV_ALPHABET HUMAN_TRBD_ALPHABET HUMAN_TRBJ_ALPHABET HUMAN_TRBV_ALPHABET_MITCR HUMAN_TRGV_ALPHABET HUMAN_TRGJ_ALPHABET HUMAN_TRDV_ALPHABET HUMAN_TRDD_ALPHABET HUMAN_TRDJ_ALPHABET
+#' @aliases genealphabets HUMAN_TRAV HUMAN_TRAJ HUMAN_TRBV HUMAN_TRBD HUMAN_TRBJ HUMAN_TRBV_MITCR HUMAN_TRGV HUMAN_TRGJ HUMAN_TRDV HUMAN_TRDD HUMAN_TRDJ
 #' 
 #' @usage
-#' HUMAN_TRAV_ALPHABET
+#' HUMAN_TRAV
 #' 
-#' HUMAN_TRAJ_ALPHABET
+#' HUMAN_TRAJ
 #' 
-#' HUMAN_TRBV_ALPHABET
+#' HUMAN_TRBV
 #' 
-#' HUMAN_TRBD_ALPHABET
+#' HUMAN_TRBD
 #' 
-#' HUMAN_TRBJ_ALPHABET
+#' HUMAN_TRBJ
 #' 
-#' HUMAN_TRBV_ALPHABET_MITCR
+#' HUMAN_TRBV_MITCR
 #' 
-#' HUMAN_TRGV_ALPHABET
+#' HUMAN_TRGV
 #' 
-#' HUMAN_TRGJ_ALPHABET
+#' HUMAN_TRGJ
 #' 
-#' HUMAN_TRDV_ALPHABET
+#' HUMAN_TRDV
 #' 
-#' HUMAN_TRDD_ALPHABET
+#' HUMAN_TRDD
 #' 
-#' HUMAN_TRDJ_ALPHABET
+#' HUMAN_TRDJ
 #' 
 #' @description
 #' Character vector with names for segments. With \code{tcR} we provided alphabets for all alpha, beta,
 #' gamma and delta chains gene segments.
 #' 
 #' @format
-#' Each \code{<SPECIES>_<GENES>_ALPHABET} is a character vector. <SPECIES> is an identifier of species, <GENES> is concatenated three
+#' Each \code{<SPECIES>_<GENES>} is a character vector. <SPECIES> is an identifier of species, <GENES> is concatenated three
 #' identifiers of cell type ("TR**" for TCR, "IG**" for Ig), chain (e.g., "**A*" for alpha chains) and gene segment ("***V" for V(ariable) gene segment, 
 #' "***J" for J(oining) gene segment, "***D" for D(iversity) gene segment).
 #' 
 #' @examples
 #' \dontrun{
-#' HUMAN_TRBV_ALPHABET[1]  #  => "TRBV10-1"
+#' HUMAN_TRBV[1]  #  => "TRBV10-1"
 #' }
-HUMAN_TRAV_ALPHABET <- c('TRAV1-1', 'TRAV1-2', 'TRAV10', 'TRAV11', 'TRAV12-1', 'TRAV12-2', 'TRAV12-3', 'TRAV13-1',
+HUMAN_TRAV <- c('TRAV1-1', 'TRAV1-2', 'TRAV10', 'TRAV11', 'TRAV12-1', 'TRAV12-2', 'TRAV12-3', 'TRAV13-1',
                          'TRAV13-2', 'TRAV14/DV4', 'TRAV16', 'TRAV17', 'TRAV18', 'TRAV19', 'TRAV2', 'TRAV20',
                          'TRAV21', 'TRAV22', 'TRAV23/DV6', 'TRAV24', 'TRAV25', 'TRAV26-1', 'TRAV26-2', 'TRAV27',
                          'TRAV29/DV5', 'TRAV3', 'TRAV30', 'TRAV34', 'TRAV35', 'TRAV36/DV7', 'TRAV38-1', 'TRAV38-2/DV8',
                          'TRAV39', 'TRAV4', 'TRAV40', 'TRAV41', 'TRAV5', 'TRAV6', 'TRAV7', 'TRAV8-1',
                          'TRAV8-2', 'TRAV8-3', 'TRAV8-4', 'TRAV8-6', 'TRAV8-7', 'TRAV9-1', 'TRAV9-2')
-HUMAN_TRAJ_ALPHABET <- c('TRAJ10', 'TRAJ11', 'TRAJ12', 'TRAJ13', 'TRAJ14', 'TRAJ15', 'TRAJ16', 'TRAJ17',
+HUMAN_TRAJ <- c('TRAJ10', 'TRAJ11', 'TRAJ12', 'TRAJ13', 'TRAJ14', 'TRAJ15', 'TRAJ16', 'TRAJ17',
                          'TRAJ18', 'TRAJ20', 'TRAJ21', 'TRAJ22', 'TRAJ23', 'TRAJ24', 'TRAJ26', 'TRAJ27',
                          'TRAJ28', 'TRAJ29', 'TRAJ3', 'TRAJ30', 'TRAJ31', 'TRAJ32', 'TRAJ33', 'TRAJ34',
                          'TRAJ36', 'TRAJ37', 'TRAJ38', 'TRAJ39', 'TRAJ4', 'TRAJ40', 'TRAJ41', 'TRAJ42',
@@ -104,30 +104,30 @@ HUMAN_TRAJ_ALPHABET <- c('TRAJ10', 'TRAJ11', 'TRAJ12', 'TRAJ13', 'TRAJ14', 'TRAJ
                          'TRAJ50', 'TRAJ52', 'TRAJ53', 'TRAJ54', 'TRAJ56', 'TRAJ57', 'TRAJ6', 'TRAJ7',
                          'TRAJ8', 'TRAJ9')
 
-HUMAN_TRBV_ALPHABET <- c('TRBV10-1', 'TRBV10-2', 'TRBV10-3', 'TRBV11-1', 'TRBV11-2', 'TRBV11-3', 'TRBV12-4', 'TRBV12-3',
+HUMAN_TRBV <- c('TRBV10-1', 'TRBV10-2', 'TRBV10-3', 'TRBV11-1', 'TRBV11-2', 'TRBV11-3', 'TRBV12-4', 'TRBV12-3',
                          'TRBV12-5', 'TRBV13', 'TRBV14', 'TRBV15', 'TRBV16', 'TRBV18', 'TRBV19', 'TRBV2',
                          'TRBV20-1', 'TRBV21-1', 'TRBV23-1', 'TRBV24-1', 'TRBV25-1', 'TRBV27', 'TRBV28', 'TRBV29-1',
                          'TRBV3-1', 'TRBV30', 'TRBV4-1', 'TRBV4-2', 'TRBV4-3', 'TRBV5-1', 'TRBV5-4', 'TRBV5-5',
                          'TRBV5-6', 'TRBV5-8', 'TRBV6-1', 'TRBV6-3', 'TRBV6-2', 'TRBV6-4', 'TRBV6-5', 'TRBV6-6',
                          'TRBV6-7', 'TRBV7-1', 'TRBV7-2', 'TRBV7-3', 'TRBV7-4', 'TRBV7-6', 'TRBV7-7', 'TRBV7-8',
                          'TRBV7-9', 'TRBV9')
-HUMAN_TRBD_ALPHABET <- c('TRBD1', 'TRBD2')
-HUMAN_TRBJ_ALPHABET <- c('TRBJ1-1', 'TRBJ1-2', 'TRBJ1-3', 'TRBJ1-4', 'TRBJ1-5', 'TRBJ1-6', 'TRBJ2-1', 'TRBJ2-2',
+HUMAN_TRBD <- c('TRBD1', 'TRBD2')
+HUMAN_TRBJ <- c('TRBJ1-1', 'TRBJ1-2', 'TRBJ1-3', 'TRBJ1-4', 'TRBJ1-5', 'TRBJ1-6', 'TRBJ2-1', 'TRBJ2-2',
                          'TRBJ2-3', 'TRBJ2-4', 'TRBJ2-5', 'TRBJ2-6', 'TRBJ2-7')
 
-HUMAN_TRBV_ALPHABET_MITCR <- c('TRBV10-1', 'TRBV10-2', 'TRBV10-3', 'TRBV11-1', 'TRBV11-2', 'TRBV11-3', 'TRBV12-4, TRBV12-3',
+HUMAN_TRBV_MITCR <- c('TRBV10-1', 'TRBV10-2', 'TRBV10-3', 'TRBV11-1', 'TRBV11-2', 'TRBV11-3', 'TRBV12-4, TRBV12-3',
                                'TRBV12-5', 'TRBV13', 'TRBV14', 'TRBV15', 'TRBV16', 'TRBV18', 'TRBV19', 'TRBV2',
                                'TRBV20-1', 'TRBV21-1', 'TRBV23-1', 'TRBV24-1', 'TRBV25-1', 'TRBV27', 'TRBV28', 'TRBV29-1',
                                'TRBV3-1', 'TRBV30', 'TRBV4-1', 'TRBV4-2', 'TRBV4-3', 'TRBV5-1', 'TRBV5-4', 'TRBV5-5',
                                'TRBV5-6', 'TRBV5-8', 'TRBV6-1', 'TRBV6-3, TRBV6-2', 'TRBV6-4', 'TRBV6-5', 'TRBV6-6', 'TRBV6-7',
                                'TRBV7-1', 'TRBV7-2', 'TRBV7-3', 'TRBV7-4', 'TRBV7-6', 'TRBV7-7', 'TRBV7-8', 'TRBV7-9', 'TRBV9')
 
-HUMAN_TRGV_ALPHABET <- c()
-HUMAN_TRGJ_ALPHABET <- c()
+HUMAN_TRGV <- c()
+HUMAN_TRGJ <- c()
 
-HUMAN_TRDV_ALPHABET <- c()
-HUMAN_TRDD_ALPHABET <- c()
-HUMAN_TRDJ_ALPHABET <- c()
+HUMAN_TRDV <- c()
+HUMAN_TRDD <- c()
+HUMAN_TRDJ <- c()
 
 
 #' Segment data.
