@@ -26,7 +26,7 @@
 #' @param .frame Which *-frames to choose.
 #' @param .head Parameter to the head() function. Supply 0 to get all elements. \code{head} applied before subsetting, i.e.
 #' if .head == 500, you will get in-frames from the top 500 clonotypes.
-#' @param .coding If T than return only coding sequences, i.e. without stop-codon.
+#' @param .coding if T then return only coding sequences, i.e. without stop-codon.
 #' 
 #' @return Filtered data.frame or a list with such data.frames.
 get.inframes <- function (.data, .head = 0, .coding = T) { 
@@ -75,16 +75,16 @@ clonotypescount <- function(.data, .head = 0) {
 
 #' MiTCR data frame basic statistics.
 #' 
-#' @aliases mitcr.stats lib.mitcr.stats
+#' @aliases cloneset.stats repseq.stats
 #' 
 #' @usage
-#' mitcr.stats(.data, .head = 0)
+#' cloneset.stats(.data, .head = 0)
 #' 
-#' lib.mitcr.stats(.data, .head = 0)
+#' repseq.stats(.data, .head = 0)
 #' 
 #' @description
 #' Compute basic statistics of TCR repertoires: number of clones, number of clonotypes, 
-#' number of in-frame and out-of-frame sequences, summary of "Read.count", "Barcode.count" and other.
+#' number of in-frame and out-of-frame sequences, summary of "Read.count", "Umi.count" and other.
 #' 
 #' @param .data tcR data frames or a list with tcR data frames.
 #' @param .head How many top clones use to comput summary.
@@ -95,12 +95,12 @@ clonotypescount <- function(.data, .head = 0) {
 #' @examples
 #' \dontrun{
 #' # Compute basic statistics of list with data frames.
-#' mitcr.stats(immdata)
-#' lib.mitcr.stats(immdata)
+#' cloneset.stats(immdata)
+#' repseq.stats(immdata)
 #' }
-mitcr.stats <- function (.data, .head = 0) {
+cloneset.stats <- function (.data, .head = 0) {
   if (has.class(.data, 'list')) {
-    res <- t(do.call(cbind, lapply(.data, mitcr.stats, .head = .head)))
+    res <- t(do.call(cbind, lapply(.data, cloneset.stats, .head = .head)))
     row.names(res) <- names(.data)
     return(res)
   }
@@ -118,22 +118,22 @@ mitcr.stats <- function (.data, .head = 0) {
   res2 <- c(Sum = sum(.data$Read.count), summary(.data$Read.count))
   names(res2) <- sub('.', '', names(res2), fixed = T)
   names(res2) <- paste0(names(res2), '.reads')
-  if (!is.na(.data$Barcode.count)[1]) {
-    res3 <- c(Sum = sum(.data$Barcode.count), summary(.data$Barcode.count))
+  if (!is.na(.data$Umi.count)[1]) {
+    res3 <- c(Sum = sum(.data$Umi.count), summary(.data$Umi.count))
     names(res3) <- sub('.', '', names(res3), fixed = T)
-    names(res3) <- paste0(names(res3), '.barcodes')
+    names(res3) <- paste0(names(res3), '.UMIs')
     res2 <- c(res2, res3)
   }
   c(res, res2)
 }
 
-lib.mitcr.stats = function(.data, .head=0) {
+repseq.stats = function(.data, .head=0) {
   if (has.class(.data, "list")) {
-    res=do.call(cbind, lapply(.data, lib.mitcr.stats, .head=.head))
+    res=do.call(cbind, lapply(.data, repseq.stats, .head=.head))
     dimnames(res)[[2]]=names(.data)
     return(t(res))
   }else{
-    .umi <- !is.na(.data$Barcode.count[1])
+    .umi <- !is.na(.data$Umi.count[1])
     .head= if (.head==0){nrow(.data)} else {.head}
     .data=head(.data, .head)
     if (!.umi) {
@@ -141,7 +141,7 @@ lib.mitcr.stats = function(.data, .head=0) {
       names(res)=c('Clones', "Sum.reads", "Reads.per.clone")
       return(res)
     }else{
-      res=c(nrow(.data), sum(.data$'Read.count'), sum(.data$'Barcode.count'), round(sum(.data$'Read.count') / sum(.data$'Barcode.count'), digits = 2), round(sum(.data$'Barcode.count') / nrow(.data), digits = 2))
+      res=c(nrow(.data), sum(.data$'Read.count'), sum(.data$'Umi.count'), round(sum(.data$'Read.count') / sum(.data$'Umi.count'), digits = 2), round(sum(.data$'Umi.count') / nrow(.data), digits = 2))
       names(res)=c('Clones', "Sum.reads", "Sum.UMIs", "Reads.per.UMI", "UMI.per.clone")
       return(res)
     }
@@ -179,10 +179,10 @@ lib.mitcr.stats = function(.data, .head=0) {
 #' \dontrun{
 #' # Compute summary statistics of VD insertions
 #' # for each V-segment using all V-segments in the given data frame.
-#' column.summary(immdata[[1]], 'V.segments', 'Total.insertions')
+#' column.summary(immdata[[1]], 'V.gene', 'Total.insertions')
 #' # Compute summary statistics of VD insertions for each V-segment using only V-segments
-#' # from the HUMAN_TRBV_ALPHABET_MITCR
-#' column.summary(immdata[[1]], 'V.segments', 'Total.insertions', HUMAN_TRBV_ALPHABET_MITCR)
+#' # from the HUMAN_TRBV_MITCR
+#' column.summary(immdata[[1]], 'V.gene', 'Total.insertions', HUMAN_TRBV_MITCR)
 #' }
 column.summary <- function (.data, .factor.col, .target.col, .alphabet = NA, .remove.neg = T) {
   if (length(.alphabet) != 0 && !is.na(.alphabet[1])) {
@@ -204,14 +204,14 @@ insertion.stats <- function (.data) {
   if (class(.data) == 'list') {
     return(lapply(.data, insertion.stats))
   }
-  vd <- column.summary(.data, 'V.segments', 'VD.insertions', HUMAN_TRBV_ALPHABET_MITCR)
+  vd <- column.summary(.data, 'V.gene', 'VD.insertions', HUMAN_TRBV_MITCR)
   names(vd)[-1] <- paste0('VD.', names(vd)[-1])
-  dj <- column.summary(.data, 'V.segments', 'DJ.insertions', HUMAN_TRBV_ALPHABET_MITCR)
+  dj <- column.summary(.data, 'V.gene', 'DJ.insertions', HUMAN_TRBV_MITCR)
   names(dj)[-1] <- paste0('DJ.', names(dj)[-1])
-  tot <- column.summary(.data, 'V.segments', 'Total.insertions', HUMAN_TRBV_ALPHABET_MITCR)
+  tot <- column.summary(.data, 'V.gene', 'Total.insertions', HUMAN_TRBV_MITCR)
   names(tot)[-1] <- paste0('Total.', names(tot)[-1])
-  res <- merge(vd, dj, by = 'V.segments', all = T)
-  res <- merge(res, tot, by = 'V.segments', all = T)
+  res <- merge(vd, dj, by = 'V.gene', all = T)
+  res <- merge(res, tot, by = 'V.gene', all = T)
   res
 }
 
@@ -235,7 +235,7 @@ insertion.stats <- function (.data) {
 #' @param .target.col Character vector specifying name of columns in which function will search for a targets.
 #' Only first column's name will be used for matching by different method, others will match exactly.
 #' \code{.targets} should be a two-column character matrix or data frame with second column for V-segments.
-#' @param .verbose If T than print messages about the search process.
+#' @param .verbose if T then print messages about the search process.
 #' 
 #' @return Data.frame.
 #' 
@@ -247,9 +247,9 @@ insertion.stats <- function (.data) {
 #'                 .method = 'exact', .col.name = "Rank", .target.col = "CDR3.amino.acid.sequence")
 #' # Find close by levenhstein distance clonotypes with similar V-segments and return
 #' # their values in columns 'Read.count' and 'Total.insertions'.
-#' find.clonotypes(.data = twb, .targets = twb[[1]][, c('CDR3.amino.acid.sequence', 'V.segments')],
+#' find.clonotypes(.data = twb, .targets = twb[[1]][, c('CDR3.amino.acid.sequence', 'V.gene')],
 #'                 .col.name = c('Read.count', 'Total.insertions'), .method = 'lev',
-#'                 .target.col = c('CDR3.amino.acid.sequence', 'V.segments'))
+#'                 .target.col = c('CDR3.amino.acid.sequence', 'V.gene'))
 #' }
 find.clonotypes <- function (.data, .targets, .method = c('exact', 'hamm', 'lev'), .col.name = 'Read.count', .target.col = 'CDR3.amino.acid.sequence', .verbose = T) {  
   if (is.character(.targets) && length(.target.col) != 1) {
@@ -263,7 +263,7 @@ find.clonotypes <- function (.data, .targets, .method = c('exact', 'hamm', 'lev'
   }
   
   if (has.class(.data, 'data.frame')) {
-    .data <- list(Data = .data)
+    .data <- list(Sample = .data)
   }
   
   if (.method[1] == 'lev') {
@@ -382,7 +382,7 @@ find.clonotypes <- function (.data, .targets, .method = c('exact', 'hamm', 'lev'
 }
 
 
-#' Perform sequential cross starting from the top of a data.frame.
+#' Perform sequential cross starting from the top of a data frame.
 #' 
 #' @aliases top.cross top.cross.vec top.cross.plot
 #' 
@@ -398,9 +398,9 @@ find.clonotypes <- function (.data, .targets, .method = c('exact', 'hamm', 'lev'
 #' 
 #' top.cross.vec(.top.cross.res, .i, .j)
 #' 
-#' top.cross.plot(.top.cross.res, .xlab = 'Top clones', 
-#'                .ylab = 'Normalised number of shared clones',
-#'                .nrow = 2, .legend.ncol = 1, .logx = T, .logy = T)
+#' top.cross.plot(.top.cross.res, .xlab = 'Top X clonotypes', 
+#'                .ylab = 'Normalised number of shared clonotypes', .nrow = 2,
+#'                .legend.ncol = 1, .logx = T, .logy = T)
 #' 
 #' @param .data Either list of data.frames or a data.frame.
 #' @param .n Integer vector of parameter appled to the head function; same as .n in the top.fun function. See "Details" for more information.
@@ -413,12 +413,12 @@ find.clonotypes <- function (.data, .targets, .method = c('exact', 'hamm', 'lev'
 #' @param .ylab Name for a y-lab.
 #' @param .nrow Number of rows of sub-plots in the output plot.
 #' @param .legend.ncol Number of columns in the output legend.
-#' @param .logx If T than transform x-axis to log-scale.
-#' @param .logy If T than transform y-axis to log-scale.
-#' @param .verbose If T than plot a progress bar.
+#' @param .logx if T then transform x-axis to log-scale.
+#' @param .logy if T then transform y-axis to log-scale.
+#' @param .verbose if T then plot a progress bar.
 #' 
 #' @return
-#' \code{top.cross} - return list for each element in \code{.n} with intersection matrix (from \code{tcR::intersect}).
+#' \code{top.cross} - return list for each element in \code{.n} with intersection matrix (from \code{tcR::intersectClonesets}).
 #' 
 #' \code{top.cross.vec} - vector of length \code{.n} with \code{.i}:\code{.j} elements of each matrix.
 #' 
@@ -443,7 +443,7 @@ top.cross <- function (.data, .n = NA, .data2 = NULL, .type = 'ave', .norm = F,
 #   res <- lapply(.n, function(i) apply.symm(.data, cross, .head = i, .type = .type, .norm = .norm, .verbose=F))
   res <- lapply(.n, function(i) {
     if (.verbose) cat('Head == ', i, ' :\n', sep = '')
-    intersect(.data, .type, .head = i, .norm = .norm, .verbose = .verbose)})
+    intersectClonesets(.data, .type, .head = i, .norm = .norm, .verbose = .verbose)})
   names(res) <- .n
   res
 }
@@ -452,7 +452,7 @@ top.cross.vec <- function (.top.cross.res, .i, .j) {
   sapply(.top.cross.res, function (mat) mat[.i, .j] )
 }
 
-top.cross.plot <- function (.top.cross.res, .xlab = 'Top clones', .ylab = 'Normalised number of shared clones', .nrow = 2, .legend.ncol = 1, .logx = T, .logy = T) {
+top.cross.plot <- function (.top.cross.res, .xlab = 'Top X clonotypes', .ylab = 'Normalised number of shared clonotypes', .nrow = 2, .legend.ncol = 1, .logx = T, .logy = T) {
   data.names <- colnames(.top.cross.res[[1]])
   len <- length(data.names)
   ps <- lapply(1:len, function (i) { 
@@ -494,7 +494,7 @@ top.cross.plot <- function (.top.cross.res, .xlab = 'Top clones', .ylab = 'Norma
   sample.plot <- p + .colourblind.discrete(len, T)
   
   leg <- gtable_filter(ggplot_gtable(ggplot_build(sample.plot + guides(colour=guide_legend(title = 'Subject', ncol=.legend.ncol)))), "guide-box")
-  grid.arrange(do.call(arrangeGrob, c(ps, nrow = .nrow)), leg, widths=unit.c(unit(1, "npc") - leg$width, leg$width), nrow = 1, main ='Top crosses')
+  grid.arrange(do.call(arrangeGrob, c(lapply(ps, function (x) x + theme(legend.position="none")), nrow = .nrow)), leg, widths=unit.c(unit(1, "npc") - leg$width, leg$width), nrow = 1, main ='Top crosses')
 #   arrangeGrob(do.call(arrangeGrob, c(ps[1:2], nrow = .nrow)), leg, widths=unit.c(unit(1, "npc") - leg$width, leg$width), nrow = 1, main ='Top cross')
 }
 
@@ -508,11 +508,11 @@ top.cross.plot <- function (.top.cross.res, .xlab = 'Top clones', .ylab = 'Norma
 #' @param .fun Function applied to each sample.
 #' @param .n Number of iterations (i.e., size of a resulting distribution).
 #' @param .size Size of samples. For \code{.sim} == "uniform" stands for number of rows to take.
-#' For \code{.sim} == "percentage" stands for number of barcodes / read counts to take.
+#' For \code{.sim} == "percentage" stands for number of UMIs / read counts to take.
 #' @param .sim A character string indicating the type of simulation required. Possible values are
 #' "uniform" or "percentage". See "Details" for more details of type of simulation.
 #' @param .postfun Function applied to the resulting list: list of results from each processed sample.
-#' @param .verbose If T than show progress bar.
+#' @param .verbose if T then show progress bar.
 #' @param .prop.col Column with proportions for each clonotype.
 #' @param ... Further values passed to \code{.fun}.
 #' 
@@ -594,7 +594,7 @@ clonal.space.homeostasis <- function (.data, .clone.types = c(Rare = .00001,
   .clone.types <- c(None = 0, .clone.types)
   
   if (has.class(.data, 'data.frame')) {
-    .data <- list(Data = .data)
+    .data <- list(Sample = .data)
   }
   
   mat <- matrix(0, length(.data), length(.clone.types) - 1, dimnames = list(names(.data), names(.clone.types)[-1]))
